@@ -42,6 +42,13 @@ def select_contains_cast_call(expression):
                     return True
     return False
 
+def module_contains_display(expression):
+    contains_func_attribute = hasattr(expression.value, "func")
+    contains_attrname = hasattr(expression.value.func, "attrname")
+    contains_display_attr = expression.value.func.attrname == "display"
+    contains_display_func = expression.value.func.name == "display"
+    return (contains_func_attribute and contains_attrname and contains_display_attr) or (contains_func_attribute and contains_display_func)
+        
 
 def is_line_split(val):
     line = val.lineno
